@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Role::RepoFileInjector; # git description: v0.003-2-g7739761
+package Dist::Zilla::Role::RepoFileInjector; # git description: v0.004-2-g8763068
 # ABSTRACT: Create files outside the build directory
 # KEYWORDS: plugin distribution generate create file repository
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Moose::Role;
 
@@ -56,7 +56,18 @@ sub add_repo_file
     my ($self, $file) = @_;
 
     my ($pkg, undef, $line) = caller;
-    $file->_set_added_by(sprintf("%s (%s line %s)", $self->plugin_name, $pkg, $line));
+    if ($file->can('_set_added_by'))
+    {
+        $file->_set_added_by(sprintf("%s (%s line %s)", $self->plugin_name, $pkg, $line));
+    }
+    else
+    {
+        # as done in Dist::Zilla::Role::FileInjector 4.300039
+        $file->meta->get_attribute('added_by')->set_value(
+            $file,
+            sprintf("%s (%s line %s)", $self->plugin_name, $pkg, $line),
+        );
+    }
 
     $self->log_debug([ 'adding file %s', $file->name ]);
 
@@ -104,7 +115,7 @@ Dist::Zilla::Role::RepoFileInjector - Create files outside the build directory
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
